# initial configuration of Cloud SBC database
#
# VERSION=1
# CHANGES="initial version"

# Table 'sbc_vpns'
CREATE TABLE sbc_vpns (id INTEGER PRIMARY KEY, iprange VARCHAR(15) NOT NULL DEFAULT '10.0.0.0', ipaddr VARCHAR(15) NOT NULL DEFAULT '10.0.0.1', ipnetmask VARCHAR(15) NOT NULL DEFAULT '255.255.255.0', port INTEGER NOT NULL DEFAULT 1194, protocol VARCHAR(3) NOT NULL DEFAULT 'UDP');

# Table 'key_val'
INSERT INTO key_val VALUES ('is_sbc_vm', '1');
INSERT into key_val VALUES ('syslog_facility', '16');
INSERT into key_val VALUES ('logcdr', '1');
INSERT into key_val VALUES ('sip_transport_lan', 'tcp:udp');
INSERT into key_val VALUES ('sip_transport_wan', 'tcp:udp');
INSERT into key_val VALUES ('stack_active_wan', '1');
INSERT into key_val VALUES ('country', '1TR110_DE');
INSERT into key_val VALUES ('syslog_active', '0');
INSERT into key_val VALUES ('logging_message', '1');
INSERT into key_val VALUES ('logging_debug', '0');
INSERT into key_val VALUES ('loglevel_message', '2');
INSERT into key_val VALUES ('loglevel_debug', '0');
INSERT into key_val VALUES ('logserver', '127.0.0.1:514');
INSERT into key_val VALUES ('gui_mode', 'simple');
INSERT into key_val VALUES ('rtpports_wan', '6000-7000');
INSERT into key_val VALUES ('sip_bindport_wan', '5060');
INSERT into key_val VALUES ('activate', '0');
INSERT into key_val VALUES ('master', '0');
INSERT into key_val VALUES ('sip_useragent_lan', 'Cloud SBC v{FIRMWARE}');
INSERT into key_val VALUES ('sip_useragent_wan', 'Cloud SBC');
